#! /bin/sh
#
#   Module name 		: addkey.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.3


# Script name : addkey.sh
# Purpose     : Adds the datakey device driver to the Unix kernel
# Author      : S. Roberts
# Revision    : 1.00

PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


title()
{
	echo
	echo "$spc$st_us INSTALL SECURITY KEY DEVICE DRIVER $norm  Rev $rev"
}


menu()
{
	title
	echo
	echo "$spc DEFAULT UBL System Software Directory [$st_bl$ubb_path$norm]"
	echo "$spc Enter 'q' to QUIT, '^' to GO BACK, 'd' for DEFAULT or NEW DIRECTORY"
	echo
}


log()
{
	# Keeps a log of operations
	# Output sent to screen and dk_install.log

	unix_log=/etc/conf/cf.d/dk_install.log
	xenix_log=/usr/sys/conf/dk_install.log

	if [ "x$1" != "x-q" ]
	then
		echo "$spc $1"
		echo
	else
		shift
	fi
	if [ $system = "XENIX" ]
	then
		echo "$1" >> $xenix_log
	fi
	if [ $system = "UNIX" -o $system = "386ix" ]
	then
		echo "$1" >> $unix_log
	fi
}
	

su_check()
{
	# Test if SuperUser
	# If $proc = 0 then SuperUser.
	proc=`id|sed s/uid=//|sed s/\(.*//`
}


find_op_sys()
{
	# Find out what Operating System currently using
	opsys=`uname -s`
	opsys=`echo $opsys|tr '[A-Z]' '[a-z]'`
}


yes_or_no()
{
	echo "$spc Select option: $st_bl\c"
	read confirm
	echo "$norm\c"
	confirm=${confirm:-"n"}
	confirm=`echo $confirm|tr '[A-Z]' '[a-z]'`
}


make_node()
{
	# Create new node in /dev for datakey.
	/etc/mknod /dev/DATAKEY c $major 0
	chmod +rwx /dev/DATAKEY
	chown bin /dev/DATAKEY
	chgrp bin /dev/DATAKEY
}


configure_new_os()
{
	major=`./configure -j NEXTMAJOR`
	log "Next major is $major"
	./configure -c -m $major -a tsxinit tsxopen tsxclose tsxioctl
}


all_ready_installed()
{
	# For SCO Xenix only.
	check=`cat /usr/sys/conf/link_xenix|grep DATAKEY.o`
}


not_needed()
{
	echo "$spc Datakey not needed on this system."
	echo
}


install()
{
	if [ -d $ubb_path ]
	then
		find_op_sys
		case $opsys in
			scoxenix | "sco xenix" | xenix )	sco_xenix;;
			scounix | "sco unix" | unix )		sco_unix;;
			386ix )					three86ix;;
			* )					dont_know;;
		esac
		ex_flag1=true
	else
		echo "$spc UBL System System Software Directory not found."
	fi
}


xenix_abort_message()
{
	log "Installation aborted"
	log -q "To continue with installation, you must:"
	log -q
	log -q "1)  Change directory to /usr/sys/conf"
	log -q "      cd /usr/sys/conf"
	log -q
	log -q "2)  Make a backup copy of link_xenix"
	log -q "      cp link_xenix link_xenix.bak"
	log -q
	log -q "3)  Edit link_xenix"
	log -q "      vi link_xenix"
	log -q "    Insert, before the filenames ending in .a, the line"
	log -q "      DATAKEY.o \\"
	log -q
	log -q "4)  Determine the next Major Device Number"
	log -q "      ./configure -j NEXTMAJOR"
	log -q
	log -q "    Write down the value shown, 'major', for use in next steps."
	log -q
	log -q "5)  Configure new xenix:"
	log -q "      ./configure -c -m 'major' -a tsxinit tsxopen tsxclose tsxioctl"
	log -q
	log -q "6)  Create a new kernel which includes Transoft device driver"
	log -q "      ./link_xenix"
	log -q
	log -q "7)  Issue the command:"
	log -q "      ./hdinstall"
	log -q
	log -q "8)  Create a special device file"
	log -q "      cd /dev"
	log -q "      mknod DATAKEY c 'major' 0"
	log -q "      chown bin DATAKEY"
	log -q "      chgrp bin DATAKEY"
	log -q
	log -q "9)  Shutdown the system to make the new kernel effective"

	echo "$spc To find out the steps to finish the installation of the Device Driver,"
	echo "$spc read the file dk_install.log found in /usr/sys/conf"
	echo
}


sco_xenix()
{
	system="XENIX"
	echo
	all_ready_installed
	if [ -z "$check" ]
	then
		log "** Installing Security Key on $system `date` **"
		if [ -f $ubb_path/DATAKEY.o ]
		then
			log "Copying DATAKEY.o to /usr/sys/conf"
			cp $ubb_path/DATAKEY.o /usr/sys/conf/.
			echo "$spc Do you want to re-link kernel now (Y/N)"
			yes_or_no
			if [ $confirm = "y" ]
			then
				log "Copying link_xenix to link_xenix.bak"
				cp /usr/sys/conf/link_xenix /usr/sys/conf/link_xenix.bak
				# Add DATAKEY.o to link_xenix
				log "Editing linx_xenix"
				cat /usr/sys/conf/link_xenix.bak|sed -f ./addkey1_sed.sh > /usr/sys/conf/link_xenix
				if [ -f /usr/sys/conf/configure ]
				then
					# Xenix version 2.2 or above.
					cd /usr/sys/conf
					configure_new_os
					log "Creating new kernel"
					/usr/sys/conf/link_xenix
					echo "$spc Do you want to install new kernel? (Y/N)"
					yes_or_no
					if [ $confirm = "y" ]
					then
						log "Running hdinstall"
						/usr/sys/conf/hdinstall
					else
						log "Please issue the command '/usr/sys/conf/hdinstall' to install."
					fi
					if [ ! -c /dev/DATAKEY ]
					then
						log "Making new node /dev/DATAKEY"
						make_node
					fi
				else
					# Xenix versions other than 2.2 plus or 386
					log "Creating new kernel"
					/usr/sys/conf/link_xenix
					echo "$spc Do you want to install new kernel? (Y/N)"
					yes_or_no
					if [ $confirm = "y" ]
					then
						log "Running hdinstall"
						/usr/sys/conf/hdinstall
					else
						log "Please issue the command '/usr/sys/conf/hdinstall' to install."
					fi
					if [ ! -c /dev/DATAKEY ]
					then
						major=18
						log "Making new node /dev/DATAKEY"
						make_node
					fi
				fi
			else
				xenix_abort_message
			fi
		else
			log "Can not find $ubb_path/DATAKEY.o"
		fi
	else
		log "Data key already installed."
	fi
	log -q
	log
}


sco_unix()
{
	system="UNIX"
	echo
	if [ -f /etc/conf/pack.d/tsx/Driver.o ]
	then
		log "Datakey already installed."
	else
		log "** Installing Security Key on $system `date` **"
		echo "$spc Do you want to re-link kernel now? (Y/N)"
		yes_or_no
		if [ $confirm = "y" ]
		then
			if [ -d /etc/conf/pack.d/tsx ]
			then
				log "Directory /etc/conf/pack.d/tsx already exists"
			else
				log "Create directory /etc/conf/pack.d.tsx"
				mkdir /etc/conf/pack.d/tsx
			fi
			if [ -f $ubb_path/Driver.o ]
			then
				log "Copying Driver.o to /etc/conf/pack.d/tsx"
				cp $ubb_path/Driver.o /etc/conf/pack.d/tsx
				if [ -f /etc/conf/cf.d/configure ]
				then
					cd /etc/conf/cf.d
					if [ ! -c /dev/DATAKEY ]
					then
						configure_new_os
						log "Making new node /dev/DATAKEY"
						make_node
					fi
					echo "$spc Do you want to install new kernel? (Y/N)"
					yes_or_no
					if [ $confirm = "y" ]
					then
						log "Creating new kernel"
						./link_unix
						echo "$spc You must now re-boot to make the new kernel effective."
					else
						log "New kernel not installed"
						log "Please issue the command '/etc/conf/cf.d/link_unix' to install"
					fi
				else
					log "/etc/conf/cf.d/configure not found."
				fi
			else
				log "$ubb_path/Driver.o not found."
			fi
		else
			log "User abort."
		fi
	fi
	log -q
	log
}


three86ix()
{
	system="386ix"
	log "** Installing Security key on $system `date` **"
	if [ ! -f /usr/options/dtkey.name ]
	then
		exists=`type installpkg | grep "not found"`
		if [ -z "$exists" ]
		then
			installpkg
		else
			sysadm
		fi
	else
		log "Data key already installed."
	fi
}


dont_know()
{
	# Dont know what Operating System used.
	echo
	if [ -f /usr/sys/conf/link_xenix ]
	then	
		echo "$spc This Operating System appears to be SCO Xenix."
		echo "$spc Please confirm (Y/N)"
		echo
		yes_or_no
		if [ $confirm = "y" ]
		then
			sco_xenix
		else
			not_needed
		fi
	elif [ -f /etc/conf/cf.d/link_unix ]
	then	
		echo "$spc This Operating System appears to be SCO Unix."
		echo "$spc Please confirm (Y/N)"
		yes_or_no
		if [ $confirm = "y" ]
		then
			sco_unix
		else
			not_needed
		fi
	elif [ -f /etc/conf/cf.d/unix ]
	then
		echo "$spc This Operating System appears to be 386IX"
		echo "$spc Please confirm (Y/N)"
		yes_or_no
		if [ $confirm = "y" ]
		then
			three86ix
		else
			not_needed
		fi
	else
		not_needed
	fi
}


# Main
# Initialise variables:
rev="1.00"
set_attrs
spc=""
proc=""
opsys=""
confirm=""
major=""
check=""
system="Unknown"
quick=$1
ex_flag1=false

su_check;
if [ $proc = "0" ]
then
	if [ -z "$ubb_path" ]
	then
		echo "$spc Please wait ..."
		ubb_path=`where.sh ubl x`
		if [ -z "${ubb_path}" ]
		then
		    ubb_path='.'
		else
		    ubb_path=`dirname $ubb_path`
		fi
	fi

	cls.sh
	if [ "x$quick" = "x-q" ]
	then
		title
		install
	else
		while [ $ex_flag1 = false ]
		do
			menu
			echo "$spc Select option: $st_bl\c"
			read opt
			echo "$norm\c"
			case $opt in
				q | Q )		exit 1;;
				"^" )		exit 2;;
				d | D )		install;;
				"" )		cls.sh;;
				* )		ubb_path=$opt;
						install;;
			esac
		done
	fi
else
	echo "$spc You are not SuperUser. Can not continue."
fi
