#! /bin/sh
#
#   Module name 		: delkey.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.3


# Script name : delkey.sh
# Purpose     : Removes the datakey device driver from unix kernel
# Author      : S. Roberts
# Revision    : 1.00


PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


log()
{
	# Keeps a log of operations
	# Output sent to screen and dk_install.log

	unix_log=/etc/conf/cf.d/dk_install.log
	xenix_log=/usr/sys/conf/dk_install.log

	if [ "x$1" != "x-q" ]
	then
		echo "$spc $1"
		echo
	else
		shift
	fi
	if [ $system = "XENIX" ]
	then
		echo "$1" >> $xenix_log
	fi
	if [ $system = "UNIX" -o $system = "386ix" ]
	then
		echo "$1" >> $unix_log
	fi
}
	

su_check()
{
	# Test if SuperUser
	# If $proc = 0 then SuperUser.
	proc=`id|sed s/uid=//|sed s/\(.*//`
}


find_op_sys()
{
	# Find out what Operating System currently using
	opsys=`uname -s`
	opsys=`echo $opsys|tr '[A-Z]' '[a-z]'`
}


yes_or_no()
{
	echo "$spc Select option: $st_bl\c"
	read confirm
	echo "$norm\c"
	confirm=${confirm:-"n"}
	confirm=`echo $confirm|tr '[A-Z]' '[a-z]'`
}


remove_node()
{
	# Remove node in /dev for datakey.
	major=`./configure -j tsx`
	./configure -c -m $major -d
	rm -f /dev/DATAKEY 2> /dev/null
}


all_ready_installed()
{
	# For SCO Xenix only.
	check=`cat /usr/sys/conf/link_xenix|grep DATAKEY.o`
}


not_needed()
{
	echo "$spc Datakey not needed on this system."
	echo
}


de_install()
{
	su_check
	if [ $proc = "0" ]
	then
		find_op_sys
		case $opsys in
			scoxenix | "sco xenix" | xenix )	sco_xenix;;
			scounix | "sco unix" | unix )		sco_unix;;
			386ix )					three86ix;;
			* )					dont_know;;
		esac
	else
		echo "$spc You are not SuperUser. Can not continue."
	fi
}


xenix_abort_message()
{
	log "De-installation aborted"
	log
	log -q "To continue with de-installation, you must:"
	log -q
	log -q "1)  Change directory to /usr/sys/conf"
	log -q "      cd /usr/sys/conf"
	log -q
	log -q "2)  If link_xenix.bak exists in directory then:"
	log -q "      cp link_xenix.bak link_xenix"
	log -q "    If not, then edit link_xenix:"
	log -q "      vi link_xenix"
	log -q "    Remove 'DATAKEY.o \\' from file"
	log -q
	log -q "3)  Find out Major Device number for datakey"
	log -q "      ./configure -j tsx"
	log -q
	log -q "    Write down the value shown, 'major', for use in next steps."
	log -q
	log -q "4)  Configure new xenix:"
	log -q "      ./configure -c -m 'major' -d"
	log -q
	log -q "5)  Remove /dev/DATAKEY"
	log -q "      rm /dev/DATAKEY"
	log -q
	log -q "6)  Create a new kernel"
	log -q "      ./link_xenix"
	log -q
	log -q "7)  Issue the command:"
	log -q "      ./hdinstall"
	log -q
	log -q "8)  Shutdown the system to make the kernel effective"

	echo "$spc To find out the steps to finish the de-installation of the Device Driver,"
	echo "$spc read the file dk_install.log found in /usr/sys/conf"
	echo
}


sco_xenix()
{
	system="XENIX"
	all_ready_installed
	if [ -z "$check" ]
	then
		log "** De-installing security Key on $system `date` **"
		log "Removing DATAKEY.o from /usr/sys/conf"
		rm /usr/sys/conf/DATAKEY.o 2> /dev/null
		echo "$spc Do you want to re-link kernel now (Y/N)"
		yes_or_no
		if [ $confirm = "y" ]
		then
			if [ -f /usr/sys/conf/link_xenix.bak ]
			then
				log "Copying link_xenix.bak to link_xenix"
				cp /usr/sys/conf/link_xenix.bak /usr/sys/conf/link_xenix
			else
				log "Copying link_xenix to link_xenix.bak"
				cp /usr/sys/conf/link_xenix /usr/sys/conf/link_xenix.bak
				line=`cat /usr/sys/conf/link_xenix.bak|grep DATAKEY.o`
				if [ "$line" = "	DATAKEY.o \\" -o "$line" = "DATAKEY.o \\" ]
				then
					# Remove whole line if DATAKEY.o is only word on line
					cat /usr/sys/conf/link_xenix.bak|sed '/.*DATAKEY\.o.*/d' > /usr/sys/conf/link_xenix
				else
					# Remove just DATAKEY.o if anything else on same line
					cat /usr/sys/conf/link_xenix.bak|sed 's/DATAKEY\.o//' > /usr/sys/conf/link_xenix
				fi
			fi
			if [ -f /usr/sys/conf/configure ]
			then
				# Xenix version 2.2 or above.
				cd /usr/sys/conf
				if [ -c /dev/DATAKEY ]
				then
					log "Removing node /dev/DATAKEY"
					remove_node
				fi
				log "Creating new kernel"
				/usr/sys/conf/link_xenix
				echo "$spc Do you want to install new kernel? (Y/N)"
				yes_or_no
				if [ $confirm = "y" ]
				then
					log "Running hdinstall"
					/usr/sys/conf/hdinstall
				else
					log "Please issue the command '/usr/sys/conf/hdinstall' to install."
				fi
			else
				# Xenix versions other than 2.2 plus or 386
				log "Removing node /dev/DATAKEY"
				rm -f /dev/DATAKEY 2>/dev/null
				/usr/sys/conf/link_xenix
				echo "$spc Do you want to install new kernel? (Y/N)"
				yes_or_no
				if [ $confirm = "y" ]
				then
					log "Running hdinstall"
					/usr/sys/conf/hdinstall
				else
					log "Please issue the command '/usr/sys/conf/hdinstall' to install."
				fi
			fi
		else
			xenix_abort_message
		fi
	else
		log "Data key already de-installed."
	fi
	log -q
	log
}


sco_unix()
{
	system="UNIX"
	if [ ! -f /etc/conf/pack.d/tsx/Driver.o ]
	then
		log "Datakey already de-installed."
	else
		log "** De-installing Security Key on $system `date` **"
		echo "$spc Do you want to re-link kernel now? (Y/N)"
		yes_or_no
		if [ $confirm = "y" ]
		then
			if [ -d /etc/conf/pack.d/tsx ]
			then
				log "Removing directory /etc/conf/pack.d/tsx"
				rm -r /etc/conf/pack.d/tsx
				if [ -f /etc/conf/cf.d/configure ]
				then
					cd /etc/conf/cf.d
					if [ -c /dev/DATAKEY ]
					then
						log "Removing node /dev/DATAKEY"
						remove_node
					fi
					echo "$spc Do you want to install new kernel? (Y/N)"
					yes_or_no
					if [ $confirm = "y" ]
					then
						log "Creating new kernel"
						./link_unix
						echo "$spc You must now re-boot to make the new kernel effective."
					else
						log "New kernel not installed"
						log "Please issue the command '/etc/conf/cf.d/link_unix' to install"
					fi
				else
					log "/etc/conf/cf.d/configure not found."
				fi
			else
				log "/etc/conf/pack.d/tsx not found."
			fi
		else
			log "User abort."
		fi
	fi
	log -q
	log
}


three86ix()
{
	system="386ix"
	log "** De-installing Security Key on $system `date` **"
	if [ -f /usr/options/dtkey.name ]
	then
		exists=`type removepkg | grep "not found"`
		if [ -z "$exists" ]
		then
			removepkg
		else
			sysadm
		fi
	else
		log "Data key already de-installed"
	fi
}


dont_know()
{
	# Dont know what Operating System used.
	echo
	echo
	if [ -f /usr/sys/conf/link_xenix ]
	then	
		echo "$spc This Operating System appears to be SCO Xenix."
		echo "$spc Please confirm (Y/N)"
		yes_or_no
		if [ $confirm = "y" ]
		then
			sco_xenix
		else
			not_needed
		fi
	elif [ -f /etc/conf/cf.d/link_unix ]
	then	
		echo "$spc This Operating System appears to be SCO Unix."
		echo "$spc Please confirm (Y/N)"
		yes_or_no
		if [ $confirm = "y" ]
		then
			sco_unix
		else
			not_needed
		fi
	elif [ -f /etc/conf/cf.d/unix ]
	then
		echo "$spc This Operating System appears to be 386IX"
		echo "$spc Please confirm (Y/N)"
		yes_or_no
		if [ $confirm = "y" ]
		then
			three86ix
		else
			not_needed
		fi
	else
		not_needed
	fi
}


# Main
# Initialise variables:
set_attrs
spc=""
proc=""
opsys=""
confirm=""
major=""
check=""
system="Unknown"

de_install
