#! /bin/sh
#
#   Module name 		: syssoft.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.3


# Script name : syssoft.sh
# Purpose     : Manages the UBL system software directory.
# Author      : S. Roberts
# Revision    : 1.00


PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


menu()
{
	cls.sh
	echo
	echo "$spc        $st_us $PROD SYSTEM SOFTWARE ADMINISTRATION $norm  Rev $rev"
	echo
	echo "$spc 1)$st_bl createdir.sh $norm\c"
	echo "        Create the $PROD System Software Directory"
	echo "$spc 2)$st_bl loadsoft.sh $norm\c"
	echo "         Loads $PROD System Software from Media"
	echo "$spc 3)$st_bl ublver.sh $norm\c"
	echo "           Determines the $PROD Revision Number"
	echo "$spc 4)$st_bl remove.sh $norm\c"
	echo "           Removes $PROD System Software"
	if [ $PROD = UBL ]
	then
		echo "$spc 5)$st_bl hinstall.sh $norm\c"
		echo "         Installs UBL on-line help"
		echo "$spc 6)$st_bl size.sh $norm\c"
		echo "             Prints size of ubl"
	else
		echo "$spc 5)$st_bl size.sh $norm\c"
		echo "             Prints size of ubl"
	fi
	echo
	echo "$spc '?' or '<NUMBER>?' for HELP, '^' to GO BACK or 'q' to QUIT\n"
}


pause()
{
	echo
	echo "$spc Press [RETURN] to continue: \c"
	read nothing
}


endhelp()
{
	echo "$spc Press [RETURN] to continue: $st_bl\c"
	read menu_ret
	echo "$norm\c"
}

help_0()
{
	echo
	echo "$spc The $PROD System Software Administration utility gives the"
	echo "$spc user access to the first steps involved in setting up a"
	echo "$spc new $PROD system."
	echo
}

help_1()
{
	echo
	echo "$spc Creates the $PROD system software directory with rwx"
	echo "$spc permissions.  The user is prompted for a directory, a"
	echo "$spc warning is given if the directory exists."
	echo
}

help_2()
{
	echo
	echo "$spc Loads the $PROD software from media.  The user is"
	echo "$spc prompted for a directory to load the software into"
	echo "$spc and the name of the device."
	echo
}

help_3()
{
	echo
	echo "$spc Returns the version number of $PROD."
	echo "$spc e.g."
	echo "$spc    $PROD v3.10 built on 1-May-92"
	echo
}

help_4()
{
	echo
	echo "$spc Removes the $PROD system software directory. The"
	echo "$spc user is prompted for a directory which must contain"
	echo "$spc $PROD.  Before the directory and its contents are"
	echo "$spc removed, the user is prompted for verification."
	echo
}

help_5()
{
	echo
	echo "$spc Loads the HELP database from media and runs a UBL"
	echo "$spc program to test it."
	echo
}

help_6()
{
	echo
	echo "$spc Prints size of the $PROD executable and static data"
	echo
}

check_4_quit()
{
	if [ $? = "1" ]
	then
		exit 1
	fi
}


# Main
rev="1.00"
if [ -n "`pwd | grep usql`" ] ; then PROD="U/SQL" ; else PROD="UBL" ; fi
set_attrs
spc=""
ex_flag1=false
while [ $ex_flag1 = false ]
do
	menu
	echo "$spc Select option: $st_bl\c"
	read opt
	echo "$norm\c"
	if [ $PROD = UBL ]
	then
		case $opt in
			1 )		createdir.sh;
					check_4_quit;
					pause;;
			2 )		loadsoft.sh;
					check_4_quit;
					pause;;
			3 )		ublver.sh;
					check_4_quit;
					pause;;
			4 )		remove.sh;
					check_4_quit;
					pause;;
			5 )		hinstall.sh;
					check_4_quit;
					pause;;
			6 )		size.sh;
					check_4_quit;
					pause;;

			\? )		help_0;
					endhelp;;
			1\? )		help_1;
					endhelp;;
			2\? )		help_2;
					endhelp;;
			3\? )		help_3;
					endhelp;;
			4\? )		help_4;
					endhelp;;
			5\? )		help_5;
					endhelp;;
			6\? )		help_6;
					endhelp;;

			"^" )		exit 2;;
			q | Q )		exit 1;;
		esac
	else
		case $opt in
			1 )		createdir.sh;
					check_4_quit;
					pause;;
			2 )		loadsoft.sh;
					check_4_quit;
					pause;;
			3 )		ublver.sh;
					check_4_quit;
					pause;;
			4 )		remove.sh;
					check_4_quit;
					pause;;
			5 )		size.sh;
					check_4_quit;
					pause;;

			\? )		help_0;
					endhelp;;
			1\? )		help_1;
					endhelp;;
			2\? )		help_2;
					endhelp;;
			3\? )		help_3;
					endhelp;;
			4\? )		help_4;
					endhelp;;
			5\? )		help_6;
					endhelp;;

			"^" )		exit 2;;
			q | Q )		exit 1;;
		esac
	fi
done
