#! /bin/sh
#
#   Module name 		: tdfutils.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.4


# Script name : tdfutils.sh
# Description : Terminal Definition File generation and modifier.
# Author      : S. Roberts
# Revision    : 1.00
#
# (C) Transoft Ltd 1992
#
# Switch      : -3   Hide option 3.


PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


menu()
{
	cls.sh
	echo
	echo "$spc        $st_us TDF GENERATOR \c"
	if [ "x$allow_opt3" != "x-3" ]
	then
		echo "AND MODIFIER \c"
	fi
	echo "$norm  Rev $rev\n"
	echo "$spc Your current terminal type (\$TERM) is $st_bl$TERM$norm"
	echo
	echo "$spc 1)                      Change terminal type"
	echo "$spc 2)                      Generate new TDF"
	if [ "x$allow_opt3" != "x-3" ]
	then
		echo "$spc 3)                      Modify TDF"
	fi
	echo
	echo "$spc '?' or '<NUMBER>?' for HELP, '^' to GO BACK or 'q' to QUIT"
}


menu0()
{
	cls.sh
	echo
	echo "$spc$st_us TDF GENERATOR AND MODIFIER $norm  Rev $rev"
	echo
	echo "$spc DEFAULT $PROD System Software Directory [$st_bl$ubb_path$norm]"
	echo "$spc Enter 'q' to QUIT, '^' to GO BACK, 'd' for DEFAULT or NEW DIRECTORY"
	echo
}


pause()
{
	echo
	echo "$spc Press [RETURN] to continue: \c"
	read nothing
}


endhelp()
{
	echo "$spc Press [RETURN] to continue: $st_bl\c"
	read menu_ret
	echo "$norm\c"
}


help_0()
{
	echo
	echo "$spc The TDF Generator and Modifier utility gives the user"
	echo "$spc access to the Terminal Definition File (TDF) utilities."
	echo
	echo "$spc These utilities allow the user to change the terminal type,"
	echo "$spc generate a new TDF or modify an existing one."
	echo
}


help_1()
{
	echo
	echo "$spc Changes the operating system environment variable \$TERM."
	echo "$spc This may be required by the Terminal Definition File (TDF)"
	echo "$spc generator."
	echo
}


help_2()
{
	echo
	echo "$spc Generates a new Terminal Definition File (TDF) for whatever"
	echo "$spc \$TERM is set to."
	echo
}


help_3()
{
	echo
	echo "$spc Modify an existing Terminal Definition File (TDF)."
	echo
}


find_ubb_dir()
{
	if [ -z "$ubb_path" ]
	then
		ubb_path=`where.sh ubl x`
		if [ -z "${ubb_path}" ]
		then
		    ubb_path='.'
		else
		    ubb_path=`dirname $ubb_path`
		fi
	fi
	ex_flag0=false
	while [ $ex_flag0 = false ]
	do
		menu0
		echo "$spc Select option: $st_bl\c"
		read opt
		echo "$norm\c"
		case $opt in
			q | Q )		exit 1;;
			"^" )		exit 2;;
			d | D )		tdf_stuff;;
			"" )		;;
			* )		check_dir;;
		esac
	done
}


check_dir()
{
	if [ -f $opt/ubl ]
	then
		ubb_path=$opt
		tdf_stuff
	else
		echo	
		echo "$spc UBL not found in directory $opt"
		pause
	fi
}


tdf_stuff()
{
	default_tdf
	option=0
	ex_flag1=false
	while [ $ex_flag1 = false ]
	do
		menu
		echo
		echo "$spc Select option: $st_bl\c"
		read option
		echo "$norm\c"
		case $option in
			1 )		echo "\n$spc Enter terminal type: $st_bl\c";
					read TERM;
					export TERM;
					echo "$norm\c";
					cls.sh;;
			2 )		generate_tdf;;
			3 )		modify_tdf_or_not $allow_opt3;;

			\? )		help_0;
					endhelp;;
			1\? )		help_1;
					endhelp;;
			2\? )		help_2;
					endhelp;;
			3\? )		help_3;
					endhelp;;

			q | Q )		exit 1;;
			"^" )		ex_flag1=true;;
			* )		;;
		esac
	done
}


default_tdf()
{
	# If BBTERM is not set or invalid, pick one.
	if [ ! -f "$BBTERM" ]
	then
		take_a_guess
		export BBTERM
	fi
}


take_a_guess()
{
	case $TERM in
		vt | vt100 | vt220 | vt320 )		BBTERM=vt220.tdf;;
		an | ans | ansi )			BBTERM=ansi.tdf;;
		wy | wyse | wy60 | wyse60 )		BBTERM=wyse60.tdf;;
		wy50 | wyse50 )				BBTERM=wyse50.tdf;;
		x | xterm )				BBTERM=av300.tdf;;
		ibm3151 | i3151 | 3151 )		BBTERM=ibm3151.tdf;;
		ampex | d80 | dialogue | dialogue80 )	BBTERM=ampex.tdf;;
		dg | d412 | d412+ )			BBTERM=d412.tdf;;
		* )					BBTERM=vt100.tdf;;
	esac
}


generate_tdf()
{
	echo "\n$spc Enter TDF filename: $st_bl\c"
	read tdf_file
	echo "$norm\c"
	if [ $PROD = U/SQL ]
	then
		tdf_file=`where.sh TDFS d`/$tdf_file
	fi
	tdfbuild.sh -v $tdf_file 2> /tmp/tdf$$.err
	more /tmp/tdf$$.err
	rm -f /tmp/tdf$$.err 2> /dev/null
        if [ -s $tdf_file ]
        then
		BBTERM=$tdf_file
		export BBTERM
		echo
		echo "$spc TDF created: $st_bl$tdf_file$norm"
		echo
		pause
        fi
}


modify_tdf_or_not()
{
	if [ "x$allow_opt3" != "x-3" ]
	then
		modify_tdf
	fi
}


modify_tdf()
{
	if [ -z "$BBENV" ]
	then
		BBENV=$ubb_path/BBENV
	fi

	if [ -n "`grep BBLIB $BBENV`" ]
	then
		ex_flag2=false
		while [ $ex_flag2 = false ]
		do
			cls.sh
			echo
			echo "\n$spc DEFAULT Modify TDF [$st_bl$BBTERM$norm]"
			echo "$spc Enter 'q' to QUIT '^' to GO BACK  'd' for DEFAULT or NEW FILENAME"
			echo "$spc Select option: $st_bl\c"
			read confirm
			echo "$norm\c"
			case $confirm in
				q | Q )		exit 1;;
				"^" )		ex_flag2=true;;
				d | D )		confirm=$BBTERM;
						call_ubb;;
				"" )		;;
				* )		call_ubb;;
			esac
		done
	else
		echo
		echo "$spc BBLIB not found in BBENV."
		echo
		pause
	fi
}


call_ubb()
{
	if [ -f $confirm ]
	then
		BBTERM=$confirm
		BBBYE=Y
		export BBBYE BBTERM
		ubl "tdfmod"
		cls.sh
		ex_flag2=true
	else
		echo
		echo "$spc $confirm not found."
		pause
	fi
}


# Main 
rev="1.00"
allow_opt3=$1
if [ -n "`pwd | grep usql`" ] ; then PROD="U/SQL" ; else PROD="UBL" ; fi
set_attrs
spc=""
if [ "x$allow_opt3" = "x-3" -o $PROD = U/SQL ]
then
	allow_opt3=-3
	tdf_stuff
	if [ "$opt" = "^" ]; then exit 2; fi
else
	find_ubb_dir
fi
